@@ -57,39 +57,34 @@ def parse_gff(gff: str, type='gene'):
                            parse_gff_attributes(attr))
 
 
-def generate_bed(gff, type='gene', canon=False):
+def generate_bed(gff, type='gene', attr_field='ID'):
     for seqid, start, end, strand, attr in parse_gff(gff, type=type):
-        gene_id = attr['ID'] if 'ID' in attr.keys() else attr['Parent'].split('_')[0]
-        if not attr.get('Parent'):
-            yield seqid, start, end, gene_id, 0, strand
-        elif attr['Parent'].endswith('_T001') or not canon:
-            yield seqid, start, end, gene_id, 0, strand
-
+        yield seqid, start, end, attr[attr_field], 0, strand
 
 def parse_arguments():
     parser = ArgumentParser(description='convert gff3 to bed12')
     parser.add_argument('gff', metavar='<input.gff3>', help='input gff3 file')
-    parser.add_argument('--canon', action='store_true', help='canonical transcripts only')
+    # parser.add_argument('--canon', action='store_true', help='canonical transcripts only')
     return parser.parse_args()
 
 
 def main():
     args = parse_arguments()
-    genes = BedTool(tuple(generate_bed(args.gff, canon=args.canon))).sort()
-    exons = BedTool(tuple(generate_bed(args.gff, type='exon', canon=args.canon))).sort()
-    cds = BedTool(tuple(generate_bed(args.gff, type='CDS', canon=args.canon))).sort()
-    for gene in genes:
+    transcripts = BedTool(tuple(generate_bed(args.gff, type='mRNA', attr_field='ID'))).sort()
+    exons = BedTool(tuple(generate_bed(args.gff, type='exon', attr_field='Parent'))).sort()
+    cds = BedTool(tuple(generate_bed(args.gff, type='CDS', attr_field='Parent'))).sort()
+    for t in transcripts:
         block_size, block_start = zip(
-            *((str(exon.stop - exon.start), str(exon.start - gene.start))
-              for exon in exons.intersect(BedTool((gene,)), nonamecheck=True)))
-        thick = tuple(cds.intersect(BedTool((gene,)), nonamecheck=True))
+            *((str(exon.stop - exon.start), str(exon.start - t.start))
+              for exon in exons.intersect(BedTool((t,)), nonamecheck=True) if exon.fields[3] == t.fields[3]))
+        thick = tuple(c for c in cds.intersect(BedTool((t,)), nonamecheck=True) if c.fields[3] == t.fields[3])
         if thick:
             thick_start = thick[0].start
             thick_stop = thick[-1].end
         else:
-            thick_start = gene.start
-            thick_stop = gene.start
-        print('\t'.join(str(x) for x in tuple(gene) + (thick_start, thick_stop,
+            thick_start = t.start
+            thick_stop = t.start
+        print('\t'.join(str(x) for x in tuple(t) + (thick_start, thick_stop,
             '0,0,0', len(block_size), ','.join(block_size)+',',
             ','.join(block_start)+',')))
 
