@@ -185,6 +185,33 @@ def parse_gene(gene, genes_path=GENES_PATH):
     return chrom, int(start), int(end)
 
 
+def gtracks(region, output, tracks=TRACKS, genes: str = 'GRCh38',
+            color_palette=COLOR_PALETTE, max=None, plot_type=['fill'],
+            overlay: bool = False, tmp_dir=None, width: int = 40,
+            genes_height: int = 2, gene_rows: int = 1, x_axis: str = 'top',
+            vlines_bed=None, bed_labels: bool = False, coord_regex=COORD_REGEX):
+    if not any(output.endswith(ext) for ext in ('pdf', 'png', 'svg')):
+        raise RuntimeError(
+            'Please make sure the output file extension is pdf, png, or svg')
+    if coord_regex.match(region):
+        chrom, xmin, xmax = parse_region(region)
+    else:
+        chrom, start, end = parse_gene(region, genes_path=genes)
+        center = (end + start) / 2
+        xmin = int(center - 0.55 * (end - start))
+        xmax = int(center + 0.55 * (end - start))
+    with tempfile.NamedTemporaryFile(dir=tmp_dir) as temp_tracks:
+        tracks_file = make_tracks_file(*tracks, vlines_bed=vlines_bed,
+            genes=genes, max=(max or ['auto']), plot_type=plot_type,
+            overlay=overlay, color_palette=color_palette,
+            genes_height=genes_height, gene_rows=gene_rows, x_axis=x_axis,
+            bed_labels=bed_labels)
+        temp_tracks.write(tracks_file.encode())
+        temp_tracks.seek(0)
+        generate_plot(f'{chrom}:{xmin}-{xmax}', temp_tracks.name, output,
+            width=width)
+
+
 def parse_arguments():
     parser = argparse.ArgumentParser(
         description=(
@@ -212,7 +239,7 @@ def parse_arguments():
     parser.add_argument(
         '--genes',
         metavar='<{path/to/genes.bed.gz,GRCh37,GRCh38,hg19,hg38,Sp9512}>',
-        default='GRCh37',
+        default='GRCh38',
         help=(
             'compressed 6-column BED file or 12-column BED12 file containing '
             'gene annotations. Alternatively, providing a genome identifier '
@@ -296,7 +323,7 @@ def parse_arguments():
     )
     args = parser.parse_args()
     for t in args.track:
-        if not any((t.endswith(ext) for ext in ('.bw', '.bdg', '.bed', 'bdg.gz', 'bed.gz'))):
+        if not any((t.endswith(ext) for ext in ('.bw', '.bdg', '.bed'))):
             raise RuntimeError(
                 'track file extensions must be one of .bw, .bdg, or .bed')
     if args.genes in set(GENOME_TO_GENES.keys()):
@@ -307,34 +334,10 @@ def parse_arguments():
 
 def main():
     args = parse_arguments()
-    if not any(args.output.endswith(ext) for ext in ('pdf', 'png', 'svg')):
-        raise RuntimeError(
-            'Please make sure the output file extension is pdf, png, or svg'
-        )
-    if args.coord_regex.match(args.region):
-        chrom, xmin, xmax = parse_region(args.region)
-    else:
-        chrom, start, end = parse_gene(args.region, genes_path=args.genes)
-        center = (end + start) / 2
-        xmin = int(center - 0.55 * (end - start))
-        xmax = int(center + 0.55 * (end - start))
-    with tempfile.NamedTemporaryFile(dir=args.tmp_dir) as temp_tracks:
-        tracks_file = make_tracks_file(
-            *args.track,
-            vlines_bed=args.vlines_bed,
-            genes=args.genes,
-            max=(args.max or ['auto']),
-            plot_type=args.plot_type,
-            overlay=args.overlay,
-            color_palette=args.color_palette,
-            genes_height=args.genes_height,
-            gene_rows=args.gene_rows,
-            x_axis=args.x_axis,
-            bed_labels=args.bed_labels
-        )
-        temp_tracks.write(tracks_file.encode())
-        temp_tracks.seek(0)
-        generate_plot(
-            f'{chrom}:{xmin}-{xmax}', temp_tracks.name, args.output,
-            width=args.width
-        )
+    gtracks(args.region, args.output, tracks=args.track, genes=args.genes,
+            color_palette=args.color_palette, max=args.max,
+            plot_type=args.plot_type, overlay=args.overlay,
+            tmp_dir=args.tmp_dir, width=args.width,
+            genes_height=args.genes_height, gene_rows=args.gene_rows,
+            x_axis=args.x_axis, vlines_bed=args.vlines_bed,
+            bed_labels=args.bed_labels, coord_regex=args.coord_regex)
